from io import StringIO
from pygments import highlight
from pygments.lexers import PythonLexer
from pygments.lexers import get_lexer_by_name
from pygments.formatters import HtmlFormatter

def src(code):
    lexer = get_lexer_by_name('lisp')
    return highlight(code, lexer, HtmlFormatter())

builddoc ={
    "HEADER1": ("h2", None),
    "HEADER2": ("h3", None),
    "HEADER3": ("h4", None),
#    "BREAK": "br",
    "TEXT": ("p", "flow-text"),
    "SRC_BEGIN": (src, None),
    "EXAMPLE": ('blockquote', None),
}


def html(doc):
    response = StringIO()
    for item in doc:
        match = builddoc.get(item.token)
        if not match:
            continue
        tag, cls = match
        if cls:
            cls = f' class="{cls}"'
        else:
            cls = ''
        if callable(tag):
            response.write(tag(item.value))
            continue
        else:
            response.write('<%s%s>%s</%s>\n' % (tag, cls, item.value, tag))
    response.seek(0)
    return response
